@@ -8,7 +8,6 @@ from pathlib import Path
 from time import sleep
 
 import rich
-from alive_progress import alive_bar
 
 from abst.config import default_creds_path
 
@@ -53,41 +52,26 @@ class Bastion:
 
     @classmethod
     def create_bastion(cls, shell: bool = False):
-        with alive_bar(7, ctrl_c=False, title="Setting up") as do_progress:
-            Bastion.shell = shell
-            print("Loading Credentials")
-            creds = None
+        Bastion.shell = shell
+        print("Loading Credentials")
+        creds = None
+        creds = cls.handle_creds_load(creds)
 
-            creds = cls.handle_creds_load(creds)
-            do_progress()
+        host, ip, port, res = cls.create_bastion_session_wrapper(creds, shell)
 
-            host, ip, port, res = cls.create_bastion_session_wrapper(creds, shell)
-            do_progress()
+        bid, response = cls.load_response(res)
 
-            bid, response = cls.load_response(res)
-            do_progress()
+        if bid is None:
+            rich.print(f"Failed to Create Bastion with response '{response}'")
+            return
+        else:
+            rich.print(f"Created Session with id '{bid}'")
 
-            if bid is None:
-                rich.print(f"Failed to Create Bastion with response '{response}'")
-                return
-            else:
-                rich.print(f"Created Session with id '{bid}'")
+        cls.wait_for_prepared()
 
-            do_progress()
-
-            cls.wait_for_prepared()
-
-            do_progress()
-
-            sleep(1)  # Precaution
-
-            do_progress()
-
-            ssh_tunnel_arg_str = cls.run_ssh_tunnel_wrapper(bid, host, ip, port, shell)
-
-            do_progress()
-            do_progress()
+        sleep(1)  # Precaution
 
+        ssh_tunnel_arg_str = cls.run_ssh_tunnel_wrapper(bid, host, ip, port, shell)
 
         while status := (sdata := cls.get_bastion_state()["data"])["lifecycle-state"] == "ACTIVE":
             deleted = cls.connect_till_deleted(sdata, ssh_tunnel_arg_str, status, shell)
@@ -155,9 +139,8 @@ class Bastion:
     @classmethod
     def write_creds_json(cls, td: dict):
         creds_path = default_creds_path
-        if not creds_path.exists():
-            with open(str(creds_path), "w") as f:
-                json.dump(td, f, indent=4)
+        with open(str(creds_path), "w") as f:
+            json.dump(td, f, indent=4)
         return creds_path
 
     @classmethod
@@ -213,7 +196,7 @@ class Bastion:
         host = creds["host"]
         bastion_id = creds["bastion-id"]
         name = creds["default-name"]
-        ssh_path = str(Path(creds["ssh-pub-path"]).resolve().absolute())
+        ssh_path = str(Path(creds["ssh-pub-path"]).resolve().expanduser())
         ip = creds["target-ip"]
         port = creds["target-port"]
         ttl = creds["ttl"]
@@ -222,7 +205,7 @@ class Bastion:
     @classmethod
     def generate_sample_dict(cls):
         td = dict()
-        td["delete_this"] = "Delete This Key after you Fill this file with your credentials"
+        td["delete_this"] = "Delete This Line after you Fill this file with your credentials"
         td["host"] = "host.bastion.us-phoenix-1.oci.oraclecloud.com"
         td["bastion-id"] = "ocid1.bastion......"
         td["default-name"] = "My super cool name"
